@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: main.c,v 1.15 2004/05/07 23:08:03 holtmann Exp $
+ *  $Id: main.c,v 1.16 2004/07/04 15:44:13 holtmann Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -227,7 +227,8 @@ static void configure_device(int hdev)
 	/* Set device name */
 	if (device_opts->name) {
 		change_local_name_cp cp;
-		expand_name(cp.name, device_opts->name, hdev);
+		memset(cp.name, 0, sizeof(cp.name));
+		expand_name(cp.name, sizeof(cp.name), device_opts->name, hdev);
 
 		hci_send_cmd(s, OGF_HOST_CTL, OCF_CHANGE_LOCAL_NAME,
 			CHANGE_LOCAL_NAME_CP_SIZE, (void *) &cp);
