@@ -190,7 +190,7 @@ typedef union YYSTYPE {
 	long  num;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 194 "y.tab.c"
+#line 194 "parser.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -202,7 +202,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 206 "y.tab.c"
+#line 206 "parser.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -1439,7 +1439,7 @@ yyreduce:
     }
 
 /* Line 999 of yacc.c.  */
-#line 1443 "y.tab.c"
+#line 1443 "parser.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
