@@ -1,26 +1,35 @@
 /*
  *
- *  RFCOMM configuration utility
+ *  BlueZ - Bluetooth protocol stack for Linux
  *
- *  Copyright (C) 2002-2003  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2002-2004  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as
+ *  published by the Free Software Foundation;
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+ *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF THIRD PARTY RIGHTS.
+ *  IN NO EVENT SHALL THE COPYRIGHT HOLDER(S) AND AUTHOR(S) BE LIABLE FOR ANY
+ *  CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES 
+ *  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN 
+ *  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF 
+ *  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  ALL LIABILITY, INCLUDING LIABILITY FOR INFRINGEMENT OF ANY PATENTS, 
+ *  COPYRIGHTS, TRADEMARKS OR OTHER RIGHTS, RELATING TO USE OF THIS 
+ *  SOFTWARE IS DISCLAIMED.
  *
+ *
+ *  $Id: main.c,v 1.12 2004/05/09 09:35:52 holtmann Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -250,7 +259,7 @@ static void cmd_connect(int ctl, int dev, bdaddr_t *bdaddr, int argc, char **arg
 	struct sigaction sa;
 	struct pollfd p;
 	char dst[18], devname[MAXPATHLEN];
-	int sk, fd, alen;
+	int sk, fd, alen, try = 3;
 
 	laddr.rc_family = AF_BLUETOOTH;
 	bacpy(&laddr.rc_bdaddr, bdaddr);
@@ -270,7 +279,6 @@ static void cmd_connect(int ctl, int dev, bdaddr_t *bdaddr, int argc, char **arg
 			fprintf(stderr, "Can't find a config entry for rfcomm%d\n", dev);
 			return;
 		}
-
 	} else {
 		raddr.rc_family = AF_BLUETOOTH;
 		str2ba(argv[1], &raddr.rc_bdaddr);
@@ -320,10 +328,21 @@ static void cmd_connect(int ctl, int dev, bdaddr_t *bdaddr, int argc, char **arg
 	}
 
 	snprintf(devname, MAXPATHLEN - 1, "/dev/rfcomm%d", dev);
-	if ((fd = open(devname, O_RDONLY | O_NOCTTY)) < 0) {
+	while ((fd = open(devname, O_RDONLY | O_NOCTTY)) < 0) {
 		snprintf(devname, MAXPATHLEN - 1, "/dev/bluetooth/rfcomm/%d", dev);
 		if ((fd = open(devname, O_RDONLY | O_NOCTTY)) < 0) {
+			if (try--) {
+				snprintf(devname, MAXPATHLEN - 1, "/dev/rfcomm%d", dev);
+				sleep(1);
+				continue;
+			}
 			perror("Can't open RFCOMM device");
+
+			memset(&req, 0, sizeof(req));
+			req.dev_id = dev;
+			req.flags = (1 << RFCOMM_HANGUP_NOW);
+			ioctl(ctl, RFCOMMRELEASEDEV, &req);
+
 			close(sk);
 			return;
 		}
@@ -377,7 +396,7 @@ static void cmd_listen(int ctl, int dev, bdaddr_t *bdaddr, int argc, char **argv
 	struct sigaction sa;
 	struct pollfd p;
 	char dst[18], devname[MAXPATHLEN];
-	int sk, nsk, fd, alen;
+	int sk, nsk, fd, alen, try = 3;
 
 	laddr.rc_family = AF_BLUETOOTH;
 	bacpy(&laddr.rc_bdaddr, bdaddr);
@@ -423,10 +442,21 @@ static void cmd_listen(int ctl, int dev, bdaddr_t *bdaddr, int argc, char **argv
 	}
 
 	snprintf(devname, MAXPATHLEN - 1, "/dev/rfcomm%d", dev);
-	if ((fd = open(devname, O_RDONLY | O_NOCTTY)) < 0) {
+	while ((fd = open(devname, O_RDONLY | O_NOCTTY)) < 0) {
 		snprintf(devname, MAXPATHLEN - 1, "/dev/bluetooth/rfcomm/%d", dev);
 		if ((fd = open(devname, O_RDONLY | O_NOCTTY)) < 0) {
+			if (try--) {
+				snprintf(devname, MAXPATHLEN - 1, "/dev/rfcomm%d", dev);
+				sleep(1);
+				continue;
+			}
 			perror("Can't open RFCOMM device");
+
+			memset(&req, 0, sizeof(req));
+			req.dev_id = dev;
+			req.flags = (1 << RFCOMM_HANGUP_NOW);
+			ioctl(ctl, RFCOMMRELEASEDEV, &req);
+
 			close(sk);
 			return;
 		}
@@ -536,7 +566,7 @@ static void usage(void)
 		"\n");
 
 	printf("Commands:\n");
-        for (i = 0; command[i].cmd; i++)
+	for (i = 0; command[i].cmd; i++)
 		printf("\t%-8s %-24s\t%s\n",
 			command[i].cmd,
 			command[i].opt ? command[i].opt : " ",
