@@ -109,7 +109,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: parser.y,v 1.7 2004/04/28 10:40:13 holtmann Exp $
+ *  $Id: parser.y,v 1.8 2004/08/09 08:01:52 holtmann Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -157,7 +157,7 @@ typedef union YYSTYPE {
 	bdaddr_t *bdaddr;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 161 "y.tab.c"
+#line 161 "parser.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -169,7 +169,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 173 "y.tab.c"
+#line 173 "parser.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -1144,7 +1144,7 @@ yyreduce:
     }
 
 /* Line 999 of yacc.c.  */
-#line 1148 "y.tab.c"
+#line 1148 "parser.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1365,7 +1365,7 @@ int rfcomm_read_config(char *filename)
 		snprintf(file, MAXPATHLEN, "%s/.bluetooth/rfcomm.conf", getenv("HOME"));
 
 		if ((getuid() == 0) || (access(file, R_OK) < 0))
-			snprintf(file, MAXPATHLEN, "/etc/bluetooth/rfcomm.conf");
+			snprintf(file, MAXPATHLEN, "%s/rfcomm.conf", CONFIGDIR);
 	}
 
 	if (!(yyin = fopen(file, "r")))
