@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: hciattach.c,v 1.21 2004/05/03 13:25:14 holtmann Exp $
+ *  $Id: hciattach.c,v 1.23 2004/06/23 16:30:41 holtmann Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -640,7 +640,7 @@ static int csr(int fd, struct uart_t *u, struct termios *ti)
 static int swave(int fd, struct uart_t *u, struct termios *ti)
 {
 	struct timespec tm = {0, 500000};
-	char cmd[9], rsp[100];
+	char cmd[10], rsp[100];
 	int r;
 
 	// Silicon Wave set baud rate command
@@ -833,6 +833,9 @@ struct uart_t uart[] = {
 	/* 3Com Bluetooth Card (Version 3.0) */
 	{ "3com",     0x0101, 0x0041, HCI_UART_H4,   115200, 115200, FLOW_CTL, csr  },
 
+	/* AmbiCom BT2000C Bluetooth PC/CF Card */
+	{ "bt2000c",  0x022d, 0x2000, HCI_UART_H4,    57600, 460800, FLOW_CTL, csr  },
+
 	{ NULL, 0 }
 };
 
