@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: hciconfig.c,v 1.42 2004/04/28 10:39:47 holtmann Exp $
+ *  $Id: hciconfig.c,v 1.43 2004/07/27 16:43:40 holtmann Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1003,9 +1003,12 @@ static void print_rev_broadcom(uint16_t hci_rev, uint16_t lmp_subver)
 	printf("\tFirmware %d.%d.%03d\n", hci_rev, lmp_subver >> 8, lmp_subver & 0xff);
 }
 
-static void print_rev_avm(uint16_t rev)
+static void print_rev_avm(uint16_t hci_rev, uint16_t lmp_subver)
 {
-	printf("\tFirmware 03.%d.%d\n", rev >> 8, rev & 0xff);
+	if (lmp_subver == 0x01)
+		printf("\tFirmware 03.%d.%d\n", hci_rev >> 8, hci_rev & 0xff);
+	else
+		printf("\tUnknown type\n");
 }
 
 static void cmd_revision(int ctl, int hdev, char *opt)
@@ -1038,7 +1041,7 @@ static void cmd_revision(int ctl, int hdev, char *opt)
 		print_rev_broadcom(ver.hci_rev, ver.lmp_subver);
 		break;
 	case 31:
-		print_rev_avm(ver.hci_rev);
+		print_rev_avm(ver.hci_rev, ver.lmp_subver);
 		break;
 	default:
 		printf("\tUnsupported manufacturer\n");
